Struct kvdb_rocksdb::CompactionProfile
source · [−]Expand description
Compaction profile for the database settings Note, that changing these parameters may trigger the compaction process of RocksDB on startup. https://github.com/facebook/rocksdb/wiki/Leveled-Compaction#level_compaction_dynamic_level_bytes-is-true
Fields
initial_file_size: u64L0-L1 target file size The minimum size should be calculated in accordance with the number of levels and the expected size of the database.
block_size: usizeblock size
Implementations
sourceimpl CompactionProfile
impl CompactionProfile
sourcepub fn auto<P: AsRef<Path>>(db_path: P) -> CompactionProfile
pub fn auto<P: AsRef<Path>>(db_path: P) -> CompactionProfile
Attempt to determine the best profile automatically, only Linux for now.
sourcepub fn ssd() -> CompactionProfile
pub fn ssd() -> CompactionProfile
Default profile suitable for SSD storage
sourcepub fn hdd() -> CompactionProfile
pub fn hdd() -> CompactionProfile
Slow HDD compaction profile