Struct kvdb_rocksdb::CompactionProfile [−][src]
Compaction profile for the database settings Note, that changing these parameters may trigger the compaction process of RocksDB on startup. https://github.com/facebook/rocksdb/wiki/Leveled-Compaction#level_compaction_dynamic_level_bytes-is-true
Fields
initial_file_size: u64L0-L1 target file size The minimum size should be calculated in accordance with the number of levels and the expected size of the database.
block_size: usizeblock size
Implementations
impl CompactionProfile[src]
impl CompactionProfile[src]pub fn auto(db_path: &Path) -> CompactionProfile[src]
Attempt to determine the best profile automatically, only Linux for now.
pub fn ssd() -> CompactionProfile[src]
Default profile suitable for SSD storage
pub fn hdd() -> CompactionProfile[src]
Slow HDD compaction profile