Struct kvdb_rocksdb::DatabaseConfig [−][src]
#[non_exhaustive]pub struct DatabaseConfig { pub max_open_files: i32, pub memory_budget: HashMap<u32, usize>, pub compaction: CompactionProfile, pub columns: u32, pub keep_log_file_num: i32, pub enable_statistics: bool, pub secondary: Option<PathBuf>, pub max_total_wal_size: Option<u64>, pub create_if_missing: bool, }
Database configuration
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_open_files: i32Max number of open files.
memory_budget: HashMap<u32, usize>Memory budget (in MiB) used for setting block cache size and
write buffer size for each column including the default one.
If the memory budget of a column is not specified,
DB_DEFAULT_COLUMN_MEMORY_BUDGET_MB is used for that column.
compaction: CompactionProfileCompaction profile.
columns: u32keep_log_file_num: i32Specify the maximum number of info/debug log files to be kept.
enable_statistics: boolEnable native RocksDB statistics. Disabled by default.
It can have a negative performance impact up to 10% according to https://github.com/facebook/rocksdb/wiki/Statistics.
secondary: Option<PathBuf>Open the database as a secondary instance.
Specify a path for the secondary instance of the database.
Secondary instances are read-only and kept updated by tailing the rocksdb MANIFEST.
It is up to the user to call catch_up_with_primary() manually to update the secondary db.
Disabled by default.
max_open_files is overridden to always equal -1.
May have a negative performance impact on the secondary instance
if the secondary instance reads and applies state changes before the primary instance compacts them.
More info: https://github.com/facebook/rocksdb/wiki/Secondary-instance
max_total_wal_size: Option<u64>Limit the size (in bytes) of write ahead logs More info: https://github.com/facebook/rocksdb/wiki/Write-Ahead-Log
create_if_missing: boolCreates a new database if no database exists.
Set to true by default for backwards compatibility.
Implementations
Create new DatabaseConfig with default parameters and specified set of columns.
Note that cache sizes must be explicitly set.
Safety
The number of columns must not be zero.
Returns the total memory budget in bytes.