[−][src]Struct kvdb_rocksdb::DatabaseConfig
Database configuration
Fields
max_open_files: i32Max number of open files.
memory_budget: HashMap<u32, usize>Memory budget (in MiB) used for setting block cache size and
write buffer size for each column including the default one.
If the memory budget of a column is not specified,
DB_DEFAULT_COLUMN_MEMORY_BUDGET_MB is used for that column.
compaction: CompactionProfileCompaction profile.
columns: u32keep_log_file_num: i32Specify the maximum number of info/debug log files to be kept.
Methods
impl DatabaseConfig[src]
pub fn with_columns(columns: u32) -> Self[src]
Create new DatabaseConfig with default parameters and specified set of columns.
Note that cache sizes must be explicitly set.
Safety
The number of columns must not be zero.
pub fn memory_budget(&self) -> usize[src]
Returns the total memory budget in bytes.